@@ -2,18 +2,15 @@ import ast
 import json
 import logging
 import platform
-import time
+
 
 import socketio
 from aiortc import RTCPeerConnection, RTCRtpSender
 from aiortc.contrib.media import MediaPlayer, MediaRelay
-from gsdbs.pitrack import PiH264StreamTrack
+
 
 raspberry = True
-try:
-    import picamera
-except ImportError:
-    raspberry = False
+
 
 relay = None
 webcam = None
